// =============================================================================
//   OpenGL1.5 - VCL Template (opengl15_vcl_template.zip)
// =============================================================================
//   Copyright  2003 by DGL - http://www.delphigl.com
// =============================================================================
//   Contents of this file are subject to the GNU Public License (GPL) which can
//   be obtained here : http://opensource.org/licenses/gpl-license.php
// =============================================================================
//   History :
//    Version 1.0 - Initial Release                            (Sascha Willems)
// =============================================================================

unit OpenGL15_MainForm;

interface

uses
  Windows,
  Messages,
  SysUtils,
  Classes,
  Graphics,
  Controls,
  Forms,
  Dialogs,

  dglOpenGL,
  settings,
  keys,
  shader,
  BodaMaths,
  lights,
  Figures,
  StdCtrls, ExtCtrls, ComCtrls;

type
  TGLForm = class(TForm)
    Panel1: TPanel;
    RadioButton1: TRadioButton;
    RadioButton2: TRadioButton;
    Panel3: TPanel;
    RadioButton5: TRadioButton;
    RadioButton6: TRadioButton;
    Panel4: TPanel;
    Panel5: TPanel;
    Panel2: TPanel;
    TrackBar1: TTrackBar;
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure ApplicationEventsIdle(Sender: TObject; var Done: Boolean);
    procedure FormKeyPress(Sender: TObject; var Key: Char);
    procedure TrackBar1Change(Sender: TObject);
  private
    { Private-Deklarationen }
  public
    RC        : HGLRC;
    DC        : HDC;
    ShowFPS   : Boolean;
    FontBase  : GLUInt;
    StartTick : Cardinal;
    Frames    : Integer;
    FPS       : Single;
  end;

var
  GLForm: TGLForm;
  shader_phong, shader_blinn: GLHandleARB;
  normal, v1, v2, v3: Vector3f;
  counter: Extended;
  SPEEDVARIABLE: Extended;

  CounterFrequency, StartCount, EndCount: Int64;

  Shininess: GLint;
  

implementation

{$R *.dfm}

procedure TGLForm.FormCreate(Sender: TObject);
begin
 SettingsOnInit;
 SetLightOptionsOnInit();
 shader_phong:= LoadFragmentAndVertexShader('phong.fp', 'phong.vs');
 shader_blinn:= LoadFragmentAndVertexShader('blinn.fp', 'blinn.vs');

 Shininess:= 120;

 QueryPerformanceFrequency(CounterFrequency);
end;
                                     
procedure TGLForm.FormDestroy(Sender: TObject);
begin
 SettingsOnDestroy;
end;

procedure TGLForm.ApplicationEventsIdle(Sender: TObject; var Done: Boolean);
var pos: Array[0..3] of Extended;
begin
 QueryPerformanceCounter(StartCount);

 SettingsOnIdle1;

 if (RadioButton1.Checked= true) then
  glUseProgramObjectARB(0)
 else
  if (RadioButton5.Checked= true) then
   glUseProgramObjectARB(shader_phong)
  else
   glUseProgramObjectARB(shader_blinn);
   
 counter:= counter + 1*SPEEDVARIABLE;

 glTranslatef(0, 0, -2);
 //glRotatef(counter/20, 0, 1, 0);
 
 glColor3f(1, 1, 1);

 glPushMatrix;


  glRotatef(counter/10+90, 0, 1, 0);
  glRotatef(counter/10, 0, 0, 1);
  glTranslatef(-2, 0, 0);

  DrawSphere(0, 0, 0, 0.1, 5);
  SetLightOptionsOnInit;
  glPopMatrix;

  DrawSphere(0, 0, 0, 1, 40);

 QueryPerformanceCounter(EndCount);
 SPEEDVARIABLE:= (((EndCount-StartCount)/CounterFrequency)*1000);
 SettingsOnIdle2;
 Done := False;
end;

procedure TGLForm.FormKeyPress(Sender: TObject; var Key: Char);
begin
 processKeys(Key);
end;

procedure TGLForm.TrackBar1Change(Sender: TObject);
begin
 Shininess:= TrackBar1.Position;
end;

end.
